@@ -1,6 +1,6 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	@(#) mhtime.pl 2.4 99/06/25 14:12:57
+##	@(#) mhtime.pl 2.5 99/07/25 02:04:05
 ##  Author:
 ##      Earl Hood       mhonarc@pobox.com
 ##  Description:
@@ -24,49 +24,45 @@
 ##    02111-1307, USA
 ##---------------------------------------------------------------------------##
 
+package mhonarc;
+
 ##---------------------------------------------------------------------------##
 ##      Date variables for date routines
 ##
-{
-    package mhtime;
+my %Month2Num = (
+    'jan', 0, 'feb', 1, 'mar', 2, 'apr', 3, 'may', 4, 'jun', 5, 'jul', 6,
+    'aug', 7, 'sep', 8, 'oct', 9, 'nov', 10, 'dec', 11,
+);
+my %WDay2Num = (
+    'sun', 0, 'mon', 1, 'tue', 2, 'wed', 3, 'thu', 4, 'fri', 5, 'sat', 6,
+);
 
-    %Month2Num = (
-	'jan', 0, 'feb', 1, 'mar', 2, 'apr', 3, 'may', 4, 'jun', 5, 'jul', 6,
-	'aug', 7, 'sep', 8, 'oct', 9, 'nov', 10, 'dec', 11,
-    );
-    %WDay2Num = (
-	'sun', 0, 'mon', 1, 'tue', 2, 'wed', 3, 'thu', 4, 'fri', 5, 'sat', 6,
-    );
+my @wdays = ('Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat');
+my @Wdays = ('Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday',
+	     'Friday', 'Saturday');
+my @mons   = ('Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug',
+	      'Sep', 'Oct', 'Nov', 'Dec');
+my @Mons   = ('January', 'February', 'March', 'April', 'May', 'June',
+	      'July', 'August', 'September', 'October', 'November',
+	      'December');
 
-    @weekdays = ('Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat');
-    @Weekdays = ('Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday',
-		 'Friday', 'Saturday');
-    @months   = ('Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug',
-		 'Sep', 'Oct', 'Nov', 'Dec');
-    @Months   = ('January', 'February', 'March', 'April', 'May', 'June',
-		 'July', 'August', 'September', 'October', 'November',
-		 'December');
-
-    $p_weekdays = "Mon|Tue|Wed|Thu|Fri|Sat|Sun";
-    $p_months   = "Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec";
-    $p_hrminsec = '\d{1,2}:\d\d:\d\d';
-    $p_hrmin    = '\d{1,2}:\d\d';
-    $p_day      = '\d{1,2}';
-    $p_year     = '\d\d\d\d|\d\d';
-}
+my $p_weekdays = "Mon|Tue|Wed|Thu|Fri|Sat|Sun";
+my $p_months   = "Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec";
+my $p_hrminsec = '\d{1,2}:\d\d:\d\d';
+my $p_hrmin    = '\d{1,2}:\d\d';
+my $p_day      = '\d{1,2}';
+my $p_year     = '\d\d\d\d|\d\d';
 
 ##---------------------------------------------------------------------------
 ##	Set weekday and month names.  This allows localization of
 ##	names.
 ##
 sub set_date_names {
-    package mhtime;
-
-    local(*in_wd, *in_Wd, *in_m, *in_M) = @_;
-    @weekdays = @in_wd	if scalar(@in_wd);
-    @Weekdays = @in_Wd	if scalar(@in_Wd);
-    @months   = @in_m 	if scalar(@in_m);
-    @Months   = @in_M 	if scalar(@in_M);
+    my($in_wd, $in_Wd, $in_m, $in_M) = @_;
+    @wdays = @$in_wd	if defined($in_wd) && scalar(@$in_wd);
+    @Wdays = @$in_Wd	if defined($in_Wd) && scalar(@$in_Wd);
+    @mons  = @$in_m 	if defined($in_m)  && scalar(@$in_m);
+    @Mons  = @$in_M 	if defined($in_M)  && scalar(@$in_M);
 }
 
 ##---------------------------------------------------------------------------
@@ -81,8 +77,6 @@ sub getdate {
 ##	Convert a calander time to a string.  Similar to strftime(3).
 ##
 sub time2str {
-    package mhtime;
-
     my($fmt, $time, $local) = @_;
     my($date) = "";
 
@@ -96,10 +90,10 @@ sub time2str {
 
     ## Format output
     if ($fmt =~ /\S/) {
-	$fmt =~ s/\%a/$weekdays[$wday]/g;
-	$fmt =~ s/\%A/$Weekdays[$wday]/g;
-	$fmt =~ s/\%[bh]/$months[$mon]/g;
-	$fmt =~ s/\%B/$Months[$mon]/g;
+	$fmt =~ s/\%a/$wdays[$wday]/g;
+	$fmt =~ s/\%A/$Wdays[$wday]/g;
+	$fmt =~ s/\%[bh]/$mons[$mon]/g;
+	$fmt =~ s/\%B/$Mons[$mon]/g;
 
 	$sec	  = sprintf("%02d", $sec);
 	$min	  = sprintf("%02d", $min);
@@ -135,7 +129,7 @@ sub time2str {
     } else {
 	$date = sprintf("%s %s %02d %02d:%02d:%02d ".
 				($local ? "%d" : "GMT %d"),
-			$weekdays[$wday], $months[$mon],
+			$wdays[$wday], $mons[$mon],
 			$mday, $hour, $min, $sec, $yearfull);
     }
     $date ;
@@ -170,12 +164,10 @@ sub time2str {
 ##	Contributer(s): Frank J. Manion <FJ_Manion@fccc.edu>
 ##
 sub parse_date {
-    package mhtime;
-
-    local($date) = $_[0];
-    local($wday, $mday, $mon, $yr, $time, $hr, $min, $sec, $zone);
-    local(@array);
-    local($start, $rest);
+    my($date) = $_[0];
+    my($wday, $mday, $mon, $yr, $time, $hr, $min, $sec, $zone);
+    my(@array);
+    my($start, $rest);
 
     # Try to find the date by focusing on the "\d\d:\d\d" field.
     # All parsing is then done relative to this location.
@@ -219,7 +211,7 @@ sub parse_date {
 	} elsif ( $rest =~ /^($p_year)/o ) {	# YYYY
 	    ($yr) = ($1);
 	} else {				# zilch, use current year
-	    warn "Warning: No year in date, using current\n";
+	    warn "Warning: No year in date ($date), using current\n";
 	    $yr = (localtime(time))[5];
 	}
 
@@ -241,10 +233,8 @@ sub parse_date {
 ##	year can be specifed as "yyyy" if a 4 digit year is needed.
 ##
 sub time2mmddyy {
-    package mhtime;
-
-    local($time, $fmt) = ($_[0], $_[1]);
-    local($day,$mon,$year,$ylen);
+    my($time, $fmt) = ($_[0], $_[1]);
+    my($day,$mon,$year,$ylen,$tmp);
     if ($time) {
 	($day,$mon,$year) = (localtime($time))[3,4,5];
 	$year += 1900;
@@ -274,8 +264,8 @@ sub time2mmddyy {
 ##	seconds.
 ##
 sub zone_offset_to_secs {
-    local($off) = shift;
-    local($sign, $min);
+    my($off) = shift;
+    my($sign, $min);
 
     ## Check if just an hour specification
     if (length($off) < 4) {
